summaryrefslogtreecommitdiffstats
path: root/nuttx/arch/avr/src/at90usb/at90usb_head.S
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/arch/avr/src/at90usb/at90usb_head.S')
-rwxr-xr-xnuttx/arch/avr/src/at90usb/at90usb_head.S12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/arch/avr/src/at90usb/at90usb_head.S b/nuttx/arch/avr/src/at90usb/at90usb_head.S
index 49b0e0e90b..a3f56245f7 100755
--- a/nuttx/arch/avr/src/at90usb/at90usb_head.S
+++ b/nuttx/arch/avr/src/at90usb/at90usb_head.S
@@ -46,9 +46,9 @@
* Pre-processor definitions
****************************************************************************/
-/* Stack is allocated just after .bss and before the heap */
+/* Stack is allocated just after uninitialized data and just before the heap */
-#define STACKBASE (_ebss+CONFIG_IDLETHREAD_STACKSIZE-1)
+#define STACKBASE (_enoinit+CONFIG_IDLETHREAD_STACKSIZE-1)
/* The RAMPZ register is only available for CPUs with more than 64Kb of FLASH.
* Only the AT90USB646, 647, 1286, and 1287 are supported by this file.
@@ -72,6 +72,7 @@
.global _sdata /* Start of .data section in RAM */
.global _edata /* End of .data section in RAM */
.global _eronly /* Start of .data section in FLASH */
+ .global _enoinit /* End of uninitialized data. Defined by ld.script */
.global up_lowinit /* Perform low level initialization */
.global os_start /* NuttX entry point */
@@ -263,15 +264,14 @@ __do_clear_bss:
* Heap Base
****************************************************************************/
/* This global variable is unsigned long g_heapbase and is
* exported from here only because of its coupling to other
* uses of _ebss in this file
*/
.data
.globl g_heapbase
.type g_heapbase, object
g_heapbase:
- .word _ebss+CONFIG_IDLETHREAD_STACKSIZE
+ .word _enoinit+CONFIG_IDLETHREAD_STACKSIZE
.size g_heapbase, .-g_heapbase
.end
@@ -263,15 +264,14 @@ __do_clear_bss:
* Heap Base
****************************************************************************/
- /* This global variable is unsigned long g_heapbase and is
- * exported from here only because of its coupling to other
- * uses of _ebss in this file
+ /* This global variable is unsigned long g_heapbase and is exported from
+ * here only because of its coupling to other uses of _enoinit in this file
*/
.data